Index: src/globals.h |
diff --git a/src/globals.h b/src/globals.h |
index d0717ca19a10b62401c26205e085e9e71d7c66e9..ebb6f74050c99af6ac96ebd2ffa7220eaa038915 100644 |
--- a/src/globals.h |
+++ b/src/globals.h |
@@ -1247,8 +1247,9 @@ class BinaryOperationFeedback { |
// Type feedback is encoded in such a way that, we can combine the feedback |
// at different points by performing an 'OR' operation. Type feedback moves |
// to a more generic type when we combine feedback. |
// kSignedSmall -> kNumber -> kAny |
// kInternalizedString -> kString -> kAny |
// TODO(epertoso): consider unifying this with BinaryOperationFeedback. |
class CompareOperationFeedback { |
public: |
@@ -1259,7 +1260,8 @@ class CompareOperationFeedback { |
kNumberOrOddball = 0x7, |
kInternalizedString = 0x8, |
kString = 0x18, |
- kAny = 0x3F |
+ kReceiver = 0x20, |
+ kAny = 0x7F |
}; |
}; |
@@ -1247,8 +1247,9 @@ class BinaryOperationFeedback { |
// at different points by performing an 'OR' operation. Type feedback moves |
// to a more generic type when we combine feedback. |
-// kSignedSmall -> kNumber -> kAny |
-// kInternalizedString -> kString -> kAny |
+// kSignedSmall -> kNumber -> kAny |
+// kInternalizedString -> kString -> kAny |
+// kReceiver -> kAny |
// TODO(epertoso): consider unifying this with BinaryOperationFeedback. |
class CompareOperationFeedback { |